#### Support TypeScript 4.5 (#11721, #11723, #11813 by @sosukesuzuki)

Support new TypeScript 4.5 features.

##### [`type` Modifiers on Import Names](https://devblogs.microsoft.com/typescript/announcing-typescript-4-5-beta/#type-on-import-names)

<!-- prettier-ignore -->
```ts
// Input
import { type A } from "mod";

// Prettier stable
SyntaxError: ',' expected. (1:15)

// Prettier main
import { type A } from "mod";

```

##### [Private Field Presence Checks](https://devblogs.microsoft.com/typescript/announcing-typescript-4-5-rc/#private-field-presence-checks)

<!-- prettier-ignore -->
```ts
// Input
class Foo {
  #prop1;
  method() {
    return #prop1 in this;
  }
}

// Prettier stable
SyntaxError: Private identifiers are not allowed outside class bodies. (4:12)
  2 |   #prop1;
  3 |   method() {
> 4 |     return #prop1 in this;
    |            ^
  5 |   }
  6 | }
  7 |

// Prettier main
class Foo {
  #prop1;
  method() {
    return #prop1 in this;
  }
}

```

##### [Import Assertions](https://devblogs.microsoft.com/typescript/announcing-typescript-4-5-rc/#import-assertions)

<!-- prettier-ignore -->
```ts
// Input
import obj from "./something.json" assert { type: "json" };

// Prettier stable
SyntaxError: ';' expected. (1:36)
> 1 | import obj from "./something.json" assert { type: "json" };
    |                                    ^
  2 |

// Prettier main
import obj from "./something.json" assert { type: "json" };

```

##### Handle `.mts` and `.cts`

Handle new file extensions `.mts` and `.cts`.
